--- old/usr/src/cmd/logger/logger.c	Mon Nov 11 13:47:11 2013
+++ new/usr/src/cmd/logger/logger.c	Mon Nov 11 13:47:11 2013
@@ -19,6 +19,7 @@
  * CDDL HEADER END
  */
 /*
+ * Copyright (c) 2013 Gary Mills
  * Copyright 2007 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
@@ -36,7 +37,6 @@
  * contributors.
  */
 
-#pragma ident	"%Z%%M%	%I%	%E% SMI"
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -85,8 +85,13 @@
 	"lpr",		LOG_LPR,
 	"news",		LOG_NEWS,
 	"uucp",		LOG_UUCP,
-	"cron",		LOG_CRON,
+	"bsdcron",	LOG_BSDCRON,
+	"authpriv",	LOG_AUTHPRIV,
+	"ftp",		LOG_FTP,
+	"ntp",		LOG_NTP,
 	"audit",	LOG_AUDIT,
+	"console",	LOG_CONSOLE,
+	"cron",		LOG_CRON,
 	"local0",	LOG_LOCAL0,
 	"local1",	LOG_LOCAL1,
 	"local2",	LOG_LOCAL2,
@@ -140,21 +145,21 @@
 	while ((opt = getopt(argc, argv, "it:p:f:")) != EOF)
 		switch (opt) {
 
-		    case 't':		/* tag */
+		case 't':		/* tag */
 			tag = optarg;
 			break;
 
-		    case 'p':		/* priority */
+		case 'p':		/* priority */
 			pri = pencode(optarg);
 			break;
 
-		    case 'i':		/* log process id also */
+		case 'i':		/* log process id also */
 			logflags |= LOG_PID;
 			pid_len = sprintf(tmp, "%ld", (long)getpid());
 			pid_len = (pid_len <= 0) ? 0 : pid_len +2;
 			break;
 
-		    case 'f':		/* file to log */
+		case 'f':		/* file to log */
 			if (strcmp(optarg, "-") == 0)
 				break;
 			infile = optarg;
@@ -165,7 +170,7 @@
 			}
 			break;
 
-		    default:
+		default:
 			usage();
 		}
 
@@ -359,6 +364,6 @@
 	(void) fprintf(stderr, gettext(
 	    "Usage:\tlogger string\n"
 	    "\tlogger [-i] [-f filename] [-p priority] [-t tag] "
-		"[message] ...\n"));
+	    "[message] ...\n"));
 	exit(1);
 }
--- old/usr/src/cmd/syslogd/syslogd.c	Mon Nov 11 13:47:11 2013
+++ new/usr/src/cmd/syslogd/syslogd.c	Mon Nov 11 13:47:11 2013
@@ -19,9 +19,10 @@
  * CDDL HEADER END
  */
 /*
+ * Copyright (c) 2013 Gary Mills
+ * Copyright 2012 Milan Jurik. All rights reserved.
  * Copyright 2008 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
- * Copyright 2012 Milan Jurik. All rights reserved.
  */
 
 /*
@@ -155,7 +156,12 @@
 	"lpr",		LOG_LPR,
 	"news",		LOG_NEWS,
 	"uucp",		LOG_UUCP,
+	"bsdcron",	LOG_BSDCRON,
+	"authpriv",	LOG_AUTHPRIV,
+	"ftp",		LOG_FTP,
+	"ntp",		LOG_NTP,
 	"audit",	LOG_AUDIT,
+	"console",	LOG_CONSOLE,
 	"cron",		LOG_CRON,
 	"local0",	LOG_LOCAL0,
 	"local1",	LOG_LOCAL1,
@@ -617,12 +623,10 @@
 	DPRINT1(1, "sys_poll(%u): sys_thread started\n", mythreadno);
 
 	/*
-	 * Try to process as many messages as we can without blocking on poll.
-	 * We count such "initial" messages with sys_init_msg_count and
-	 * enqueue them without the SYNC_FILE flag.  When no more data is
-	 * waiting on the local log device, we set timeout to INFTIM,
-	 * clear sys_init_msg_count, and generate a flush message to sync
-	 * the previously counted initial messages out to disk.
+	 * Process messages, blocking on poll because timeout is set
+	 * to INFTIM.  When poll returns with a message, call getkmsg
+	 * to pull up one message from the log driver and enqueue it
+	 * with the sync flag set.
 	 */
 
 	sys_init_msg_count = 0;
@@ -695,7 +699,7 @@
 		lastline = &dat.buf[dat.len];
 		*lastline = '\0';
 
-		DPRINT2(5, "sys_poll:(%u): getmsg: dat.len = %d\n",
+		DPRINT2(5, "getkmsg:(%u): getmsg: dat.len = %d\n",
 		    mythreadno, dat.len);
 		buflen = strlen(buf);
 		len = findnl_bkwd(buf, buflen);
--- old/usr/src/man/man1m/syslogd.1m	Mon Nov 11 13:47:11 2013
+++ new/usr/src/man/man1m/syslogd.1m	Mon Nov 11 13:47:11 2013
@@ -1,9 +1,10 @@
 '\" te
+.\" Copyright (c) 2013 Gary Mills
 .\" Copyright (C) 2008, Sun Microsystems, Inc. All Rights Reserved
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH SYSLOGD 1M "Oct 31, 2008"
+.TH SYSLOGD 1M "Oct 17, 2013"
 .SH NAME
 syslogd \- log system messages
 .SH SYNOPSIS
@@ -62,7 +63,7 @@
 .LP
 In an effort to reduce visual clutter, message \fBID\fRs are not displayed when
 writing to the console; message \fBID\fRs are only written to the log file.
-See .
+See \fBEXAMPLES\fR.
 .sp
 .LP
 The \fB/etc/default/syslogd\fR file contains the following default parameter
@@ -152,7 +153,7 @@
 .sp .6
 .RS 4n
 Enable the \fBsyslogd\fR \fBUDP\fR port to turn on logging of remote messages.
-This is the default behavior. See .
+This is the default behavior. See \fBEXAMPLES\fR.
 .RE
 
 .sp
@@ -163,7 +164,7 @@
 .sp .6
 .RS 4n
 Disable the \fBsyslogd\fR \fBUDP\fR port to turn off logging of remote
-messages. See .
+messages. See \fBEXAMPLES\fR.
 .RE
 
 .SH EXAMPLES
--- old/usr/src/man/man4/syslog.conf.4	Mon Nov 11 13:47:11 2013
+++ new/usr/src/man/man4/syslog.conf.4	Mon Nov 11 13:47:11 2013
@@ -1,7 +1,8 @@
 '\" te
+.\" Copyright (c) 2013 Gary Mills
 .\" Copyright (c) 2003 Sun Microsystems, Inc. All Rights Reserved.
 .\" Copyright (c) 1983 Regents of the University of California.  All rights reserved.  The Berkeley software License Agreement  specifies the terms and conditions for redistribution.
-.TH SYSLOG.CONF 4 "Apr 26, 2006"
+.TH SYSLOG.CONF 4 "Oct 17, 2013"
 .SH NAME
 syslog.conf \- configuration file for syslogd system log daemon
 .SH SYNOPSIS
@@ -48,20 +49,20 @@
 .sp
 .ne 2
 .na
-\fB\fBuser\fR\fR
+\fB\fBkern\fR\fR
 .ad
 .RS 12n
-Messages generated by user processes. This is the default priority for messages
-from programs or facilities not listed in this file.
+Messages generated by the kernel.
 .RE
 
 .sp
 .ne 2
 .na
-\fB\fBkern\fR\fR
+\fB\fBuser\fR\fR
 .ad
 .RS 12n
-Messages generated by the kernel.
+Messages generated by user processes. This is the default priority for messages
+from programs or facilities not listed in this file.
 .RE
 
 .sp
@@ -123,17 +124,42 @@
 .sp
 .ne 2
 .na
-\fB\fBcron\fR\fR
+\fB\fBbsdcron\fR\fR
 .ad
 .RS 12n
-Designated for \fBcron\fR/\fBat\fR messages generated by systems that do
-logging through \fBsyslog\fR. The current version of the Solaris Operating
-Environment does not use this facility for logging.
+Designated for the BSD cron/at system.
 .RE
 
 .sp
 .ne 2
 .na
+\fB\fBauthpriv\fR\fR
+.ad
+.RS 12n
+Designated for the BSD security/authorization system.
+.RE
+
+.sp
+.ne 2
+.na
+\fB\fBftp\fR\fR
+.ad
+.RS 12n
+Designated for the file transfer system.
+.RE
+
+.sp
+.ne 2
+.na
+\fB\fBntp\fR\fR
+.ad
+.RS 12n
+Designated for the network time system.
+.RE
+
+.sp
+.ne 2
+.na
 \fB\fBaudit\fR\fR
 .ad
 .RS 12n
@@ -141,6 +167,26 @@
 syslog.
 .RE
 
+.sp
+.ne 2
+.na
+\fB\fBconsole\fR\fR
+.ad
+.RS 12n
+Designated for the BSD console system.
+.RE
+
+.sp
+.ne 2
+.na
+\fB\fBcron\fR\fR
+.ad
+.RS 12n
+Designated for \fBcron\fR/\fBat\fR messages generated by systems that do
+logging through \fBsyslog\fR. The current version of the Solaris Operating
+Environment does not use this facility for logging.
+.RE
+
 .sp
 .ne 2
 .na
--- old/usr/src/uts/common/os/logsubr.c	Mon Nov 11 13:47:11 2013
+++ new/usr/src/uts/common/os/logsubr.c	Mon Nov 11 13:47:11 2013
@@ -20,6 +20,7 @@
  */
 
 /*
+ * Copyright (c) 2013 Gary Mills
  * Copyright (c) 1998, 2010, Oracle and/or its affiliates. All rights reserved.
  */
 
@@ -73,8 +74,8 @@
 static char log_fac[LOG_NFACILITIES + 1][LOG_FACSIZE] = {
 	"kern",		"user",		"mail",		"daemon",
 	"auth",		"syslog",	"lpr",		"news",
-	"uucp",		"resv9",	"resv10",	"resv11",
-	"resv12",	"audit",	"resv14",	"cron",
+	"uucp",		"bsdcron",	"authpriv",	"ftp",
+	"ntp",		"audit",	"console",	"cron",
 	"local0",	"local1",	"local2",	"local3",
 	"local4",	"local5",	"local6",	"local7",
 	"unknown"
--- old/usr/src/uts/common/sys/syslog.h	Mon Nov 11 13:47:12 2013
+++ new/usr/src/uts/common/sys/syslog.h	Mon Nov 11 13:47:12 2013
@@ -1,4 +1,5 @@
 /*
+ * Copyright (c) 2013 Gary Mills
  * Copyright 2003 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
@@ -19,8 +20,6 @@
 #ifndef	_SYS_SYSLOG_H
 #define	_SYS_SYSLOG_H
 
-#pragma ident	"%Z%%M%	%I%	%E% SMI"
-
 #ifdef	__cplusplus
 extern "C" {
 #endif
@@ -37,9 +36,13 @@
 #define	LOG_LPR		(6<<3)	/* line printer subsystem */
 #define	LOG_NEWS	(7<<3)	/* netnews subsystem */
 #define	LOG_UUCP	(8<<3)	/* uucp subsystem */
+#define	LOG_BSDCRON	(9<<3)	/* BSD cron/at subsystem */
+#define	LOG_AUTHPRIV	(10<<3)	/* BSD security/authorization messages */
+#define	LOG_FTP		(11<<3)	/* file transfer subsystem */
+#define	LOG_NTP		(12<<3)	/* network time subsystem */
 #define	LOG_AUDIT	(13<<3) /* audit subsystem */
+#define	LOG_CONSOLE	(14<<3) /* BSD console messages */
 #define	LOG_CRON	(15<<3)	/* cron/at subsystem */
-	/* other codes through 15 reserved for system use */
 #define	LOG_LOCAL0	(16<<3)	/* reserved for local use */
 #define	LOG_LOCAL1	(17<<3)	/* reserved for local use */
 #define	LOG_LOCAL2	(18<<3)	/* reserved for local use */
